==================
Models Reference
==================


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   
   models/ewm
   models/fft
   models/holt_winters
   models/prophet
   models/sarimax
   
   